import { useState } from "react";
import ReusableCard from "../reusableCard/index";

// const StickyNote = () => {
//   const [notes, setNotes] = useState([]);
//   const [showNote, setShowNote] = useState(false);



  const StickyNote = () => {
    const [notes, setNotes] = useState([]);
    const [showNote, setShowNote] = useState(false);

    const handleShowNote = () => {
      setShowNote(!showNote);
    };

    const handleAddNote = () => {
      setNotes([...notes, {id: Date.now(), content: ""}]);
    };

    const handleDeleteNote = (id) => {
      setNotes(notes.filter((note) => note.id !== id));
    };

    const handleSaveNote = (id, content) => {
      setNotes(
        notes.map((note) =>
        note.id === id ? {...note, content} : note
        )
      );
    };
  
  return (
    <>
      <div className="bg-yellow-300 h-30 sm:h-20 w-full text-center text-4xl">
        <p className="uppercase py-4 font-bold">Sticky Notes Application</p>
      </div>
      <div className="p-6 gap-10 flex justify-center">
        <button
          onClick={handleAddNote}
          className="border border-gray-600 bg-gray-200 rounded p-2 hover:bg-gray-500 hover:text-white transition delay-0 flex items-center justify-center"
        >
          Add Note
        </button>

        <button
          onClick={handleShowNote}
          className="border border-gray-600 bg-gray-200 rounded p-2 hover:bg-gray-500 hover:text-white transition delay-0 flex items-center justify-center"
        >
          Show Notes
        </button>
      </div>
            {showNote && (
      <div className="p-10 flex flex-wrap gap-10">

        {notes.map((note) => (
          <ReusableCard
            key={note.id}
            id={note.id}
            onDelete={() => handleDeleteNote(note.id)}
            onSave={handleSaveNote}
          />

        ))}

      </div>
            )}
    </>
  );
};

export default StickyNote;
